import { VerbosityLevel, Permissions, Outline, Info, Metadata } from './types';
export declare type PdfDataOptions = {
    /**
     * password for a password-protected PDF
     *
     * @type {string}
     */
    password?: string;
    /**
     * the number of pages to be read
     *
     * @type {number}
     */
    max?: number;
    /**
     * sort the text by text coordinates
     *
     * @type {boolean}
     */
    sort?: boolean;
    /**
     * the logging level
     *
     * @type {VerbosityLevel}
     */
    verbosity?: VerbosityLevel;
};
/**
 * the data of the pdf
 */
export declare class PdfData {
    /**
     * the number of pages
     *
     * @readonly
     * @type {number}
     */
    readonly pages: number;
    /**
     * extracted text per page
     *
     * @readonly
     * @type {string[]}
     */
    readonly text: readonly string[];
    /**
     * the fingerprint
     *
     * @readonly
     * @type {string}
     */
    readonly fingerprint: string;
    /**
     * the outline/bookmarks
     *
     * @readonly
     * @type {Outline[]}
     */
    readonly outline: readonly Outline[];
    /**
     * the informations/description
     *
     * @readonly
     * @type {Info | undefined}
     */
    readonly info?: Info;
    /**
     * the metadata
     *
     * @readonly
     * @type {Metadata | undefined}
     */
    readonly metadata?: Metadata;
    /**
     * the permission flags
     *
     * @readonly
     * @type {Permissions | undefined}
     */
    readonly permissions?: Permissions;
    private constructor();
    /**
     * get the data
     *
     * @param {Uint8Array} data - the binary data file
     * @param {PdfDataOptions} [options={}] - the options on how the data should be extracted
     * @returns {Promise<PdfData>} a promise that is resolved with a {PdfData} object with the extracted data
     */
    static extract(data: Uint8Array, options?: PdfDataOptions): Promise<PdfData>;
}
