"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PdfData = void 0;
const pdfdataextractor_1 = require("./pdfdataextractor");
/**
 * the data of the pdf
 */
class PdfData {
    constructor(pages, text, fingerprint, outline, metaData, permissions) {
        this.pages = pages;
        this.text = text;
        this.fingerprint = fingerprint;
        this.outline = outline;
        if (metaData != null) {
            this.info = metaData.info;
            this.metadata = metaData.metadata;
        }
        if (permissions)
            this.permissions = permissions;
    }
    /**
     * get the data
     *
     * @param {Uint8Array} data - the binary data file
     * @param {PdfDataOptions} [options={}] - the options on how the data should be extracted
     * @returns {Promise<PdfData>} a promise that is resolved with a {PdfData} object with the extracted data
     */
    static async extract(data, options = {}) {
        const extractor = await pdfdataextractor_1.PdfDataExtractor.get(data, {
            password: options.password,
            verbosity: options.verbosity,
        });
        const pdfdata = new PdfData(extractor.pages, await extractor.getText(options.max, options.sort), extractor.fingerprint, await extractor.getOutline(), await extractor.getMetadata(), await extractor.getPermissions());
        extractor.close();
        return pdfdata;
    }
}
exports.PdfData = PdfData;
//# sourceMappingURL=pdfdata.js.map